#[warn(clippy::all, clippy::pedantic)]
pub mod decode;
pub mod encode;
pub mod error;

#[derive(Clone, Copy)]
pub struct B32Alphabet {
    items: [char; 32],
    pad: Option<char>,
}

pub static B32_RFC4648_ALPHABET: B32Alphabet = B32Alphabet {
    items: [
        'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R',
        'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z', '2', '3', '4', '5', '6', '7',
    ],
    pad: Some('='),
};

impl Default for B32Alphabet {
    fn default() -> Self {
        B32_RFC4648_ALPHABET
    }
}

impl B32Alphabet {
    pub(crate) fn idx(&self, c: char) -> Option<usize> {
        for (idx, x) in self.items.iter().enumerate() {
            if *x == c {
                return Some(idx);
            }
        }
        None
    }

    pub(crate) fn pad(&self) -> Option<char> {
        self.pad
    }
}
